@@ -20,18 +20,19 @@
  ***************************************************************************/
 
 #include "StatisticsView.h"
-#include "StatisticsView.moc"
+
+/* the includes are needed for KDE support */
+#include <KLocalizedString>
 
 /* the includes are needed for Qt support */
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
-
-//Added by qt3to4:
 #include <QGridLayout>
+#include <QLabel>
+#include <QLayout>
+#include <QPushButton>
 
-#include <klocale.h>
-#include <kdebug.h>
+#ifdef DEBUG
+#include <QDebug>
+#endif
 
 #include "settingsclass.h"
 #include "StatisticsBarWidget.h"
@@ -41,7 +42,7 @@ StatisticsView::StatisticsView(QWidget * parent) :
     QFrame(parent), m_count(0), m_correct(0)
 {
 #ifdef DEBUG
-    kDebug() << "constructor StatisticsView()";
+    qDebug() << QStringLiteral("constructor StatisticsView()");
 #endif
     // load statistics from config file
     m_count = SettingsClass::count();
@@ -52,8 +53,6 @@ StatisticsView::StatisticsView(QWidget * parent) :
     defaultFont.setBold(true);
     defaultFont.setPointSize(28);
 
-    QPalette pal;
-
     /* create a grid to show the labels */
     labelGrid = new QGridLayout();
     setLayout(labelGrid);
@@ -130,11 +129,11 @@ StatisticsView::StatisticsView(QWidget * parent) :
 
     // add reset button and connect
     resetButton = new QPushButton(this);
-    resetButton->setObjectName("resetButton");
+    resetButton->setObjectName(QStringLiteral("resetButton"));
     resetButton->setText(i18n("&Reset"));
     resetButton->setToolTip(i18n("Click this button to reset the statistics."));
     resetButton->setFont(defaultFont);
-    QObject::connect(resetButton, SIGNAL(clicked()), this, SLOT(resetStatistics()));
+    QObject::connect(resetButton, &QPushButton::clicked, this, &StatisticsView::resetStatistics);
     labelGrid->addWidget(resetButton, 5, 5, Qt::AlignRight);
 
     /* calculate the statistics */
@@ -145,13 +144,13 @@ StatisticsView::StatisticsView(QWidget * parent) :
 StatisticsView::~StatisticsView()
 {
 #ifdef DEBUG
-    kDebug() << "destructor StatisticsView()";
+    qDebug() << QStringLiteral("destructor StatisticsView()");
 #endif
     // save statistics for next run
     SettingsClass::setCount(m_count);
     SettingsClass::setCorrect(m_correct);
     SettingsClass::setSkipped(m_skipped);
-    SettingsClass::self()->writeConfig();
+    SettingsClass::self()->save();
 
     /* no need to delete any child widgets, Qt does it by itself */
 }
@@ -188,27 +187,26 @@ void StatisticsView::calc()
     statisticsBar->updateBar(m_correct, m_skipped, m_count);
 
     QString new_text;
-    QString number;
 
-    new_text = QString("<b>%1</b>").arg(m_count);
+    new_text = QStringLiteral("<b>%1</b>").arg(m_count);
     result1Label->setText(new_text);
 
     /* we have to be careful with division by 0 */
     if (m_count == 0) {
-        result2Label->setText("0 (0 %)");
-        result3Label->setText("0 (0 %)");
-        result4Label->setText("0 (0 %)");
+        result2Label->setText(QStringLiteral("0 (0 %)"));
+        result3Label->setText(QStringLiteral("0 (0 %)"));
+        result4Label->setText(QStringLiteral("0 (0 %)"));
     } else {
         /* set the correct label */
-        new_text = QString("%1").arg(m_correct);
+        new_text = QStringLiteral("%1").arg(m_correct);
         result2Label->setText(new_text);
 
         /* set the correct label */
-        new_text = QString("%1").arg(m_skipped);
+        new_text = QStringLiteral("%1").arg(m_skipped);
         result3Label->setText(new_text);
 
         /* set the incorrect label */
-        new_text = QString("%1").arg(m_count - m_correct - m_skipped);
+        new_text = QStringLiteral("%1").arg(m_count - m_correct - m_skipped);
         result4Label->setText(new_text);
     }
 }
